import { PrismaClient } from '@prisma/client';

const prisma = new PrismaClient();

async function main() {
  console.log('Starting to seed new quizzes...');

  // Foundation Tier: Module 6 (3 lessons)
  await createQuiz(
    'quiz-6-1',
    'Cultural Sensitivity and Faith-Based Safeguarding Quiz 1',
    'Understanding Cultural Context in Safeguarding',
    [
      {
        text: 'Why is cultural awareness important in safeguarding within Islamic educational settings?',
        options: [
          'It is only important for legal compliance purposes',
          'It helps identify and address barriers to effective safeguarding',
          'It allows staff to ignore safeguarding concerns based on cultural differences',
          'It is only relevant when working with recent immigrants'
        ],
        correctOption: 1
      },
      {
        text: 'Which of the following best describes the UK Muslim community?',
        options: [
          'A homogeneous group with identical cultural practices',
          'A diverse community with varying ethnic backgrounds, cultural practices, and interpretations of Islamic teachings',
          'A community that always prioritizes cultural practices over UK law',
          'A group that is exempt from UK safeguarding regulations'
        ],
        correctOption: 1
      },
      {
        text: 'How can cultural factors influence safeguarding practices?',
        options: [
          'They have no impact on safeguarding practices',
          'They may affect communication styles, help-seeking behaviors, and views on privacy',
          'They automatically override UK safeguarding requirements',
          'They only matter when working with children who don\'t speak English'
        ],
        correctOption: 1
      },
      {
        text: 'What is cultural competence in safeguarding?',
        options: [
          'Assuming all families from the same cultural background behave identically',
          'Ignoring cultural differences to treat everyone exactly the same',
          'The ability to understand, communicate with, and effectively interact with people across cultures while maintaining safeguarding standards',
          'Allowing harmful practices if they are considered cultural traditions'
        ],
        correctOption: 2
      },
      {
        text: 'When there is a conflict between cultural practices and UK safeguarding laws, what takes precedence?',
        options: [
          'Cultural practices always take precedence',
          'UK law always takes precedence',
          'It depends on how long the family has lived in the UK',
          'It depends on the preference of the community leaders'
        ],
        correctOption: 1
      }
    ]
  );

  await createQuiz(
    'quiz-6-2',
    'Cultural Sensitivity and Faith-Based Safeguarding Quiz 2',
    'Faith-Specific Safeguarding Considerations',
    [
      {
        text: 'What are faith-specific safeguarding considerations in Islamic educational settings?',
        options: [
          'Issues that only affect Muslim children',
          'Specific safeguarding challenges and opportunities that arise in religious educational contexts',
          'Concerns that can be ignored due to religious exemptions',
          'Safeguarding issues that only religious leaders can address'
        ],
        correctOption: 1
      },
      {
        text: 'Which of the following is an example of spiritual abuse?',
        options: [
          'Teaching children about religious obligations',
          'Using religious texts or authority to control, manipulate, or intimidate children',
          'Implementing gender segregation in accordance with religious teachings',
          'Encouraging children to pray regularly'
        ],
        correctOption: 1
      },
      {
        text: 'Which Islamic principle strongly supports the concept of safeguarding children?',
        options: [
          'Zakat (charity)',
          'Sawm (fasting)',
          'Amanah (trust)',
          'Hajj (pilgrimage)'
        ],
        correctOption: 2
      },
      {
        text: 'How can religious leaders contribute to effective safeguarding?',
        options: [
          'By exempting their institutions from safeguarding requirements',
          'By handling all safeguarding concerns internally without external involvement',
          'By addressing safeguarding in sermons and clarifying Islamic positions on child protection',
          'By focusing only on religious education and leaving safeguarding to others'
        ],
        correctOption: 2
      },
      {
        text: 'What is a faith-sensitive intervention in safeguarding?',
        options: [
          'Ignoring safeguarding concerns if they involve religious practices',
          'Adapting safeguarding approaches to respect faith contexts while maintaining child protection standards',
          'Allowing religious leaders to handle all safeguarding concerns without oversight',
          'Focusing only on religious aspects of a child\'s wellbeing'
        ],
        correctOption: 1
      }
    ]
  );

  await createQuiz(
    'quiz-6-3',
    'Cultural Sensitivity and Faith-Based Safeguarding Quiz 3',
    'Balancing Cultural Respect with Child Protection',
    [
      {
        text: 'What should be the paramount consideration when balancing cultural sensitivity and child protection?',
        options: [
          'Community reputation',
          'Religious traditions',
          'Child safety and welfare',
          'Parental authority'
        ],
        correctOption: 2
      },
      {
        text: 'Which of the following statements about cultural practices is correct?',
        options: [
          'All cultural practices should be accepted regardless of their impact on children',
          'Cultural practices that harm children cannot be accepted regardless of tradition',
          'Cultural practices are exempt from UK safeguarding laws',
          'Cultural practices should only be questioned by people from the same cultural background'
        ],
        correctOption: 1
      },
      {
        text: 'What is an effective approach to addressing cultural barriers to safeguarding?',
        options: [
          'Ignoring cultural differences entirely',
          'Allowing harmful practices if they are culturally significant',
          'Building trust through consistent, fair treatment and cultural competence',
          'Requiring all families to adopt British cultural practices'
        ],
        correctOption: 2
      },
      {
        text: 'When discussing safeguarding concerns with families from diverse cultural backgrounds, what approach is most effective?',
        options: [
          'Using technical safeguarding jargon to demonstrate expertise',
          'Focusing on criticism of cultural practices',
          'Using clear language, culturally relevant examples, and focusing on child welfare',
          'Avoiding discussions about cultural aspects entirely'
        ],
        correctOption: 2
      },
      {
        text: 'How can Maktabs and Madrasahs develop cultural competence in their settings?',
        options: [
          'By hiring staff only from specific cultural backgrounds',
          'By exempting themselves from standard safeguarding requirements',
          'By providing cultural competence training, developing diverse representation, and engaging with communities',
          'By separating children according to their cultural backgrounds'
        ],
        correctOption: 2
      }
    ]
  );

  // Foundation Tier: Module 7 (3 lessons)
  await createQuiz(
    'quiz-7-1',
    'Introduction to Safe Conduct Quiz 1',
    'Appropriate Boundaries with Children',
    [
      {
        text: 'Why are professional boundaries important when working with children?',
        options: [
          'They create barriers between adults and children',
          'They protect both children from harm and adults from allegations',
          'They prevent any form of relationship developing between staff and children',
          'They are only necessary for teachers, not volunteers'
        ],
        correctOption: 1
      },
      {
        text: 'Which of the following is an example of appropriate physical contact with a child?',
        options: [
          'Hugging a child who is upset, based on the adult\'s need for connection',
          'Physically restraining a child as punishment for misbehavior',
          'A reassuring touch on the shoulder in response to a child\'s needs',
          'Regular physical contact in private settings'
        ],
        correctOption: 2
      },
      {
        text: 'What is an appropriate emotional boundary when working with children?',
        options: [
          'Sharing personal problems with children to build trust',
          'Becoming a "friend" rather than maintaining a professional relationship',
          'Creating dependency by being the child\'s main source of emotional support',
          'Maintaining a professional relationship while being supportive and caring'
        ],
        correctOption: 3
      },
      {
        text: 'How does the Islamic concept of hayaa (modesty) relate to professional boundaries?',
        options: [
          'It has no relevance to professional boundaries',
          'It guides appropriate interactions, particularly between genders',
          'It only applies to female staff members',
          'It prevents any form of safeguarding discussion'
        ],
        correctOption: 1
      },
      {
        text: 'Which of the following is a warning sign that professional boundaries may be being crossed?',
        options: [
          'Treating all children equally',
          'Maintaining appropriate physical distance',
          'Singling out a child for special attention or favoritism',
          'Discussing concerns with the Designated Safeguarding Lead'
        ],
        correctOption: 2
      }
    ]
  );

  await createQuiz(
    'quiz-7-2',
    'Introduction to Safe Conduct Quiz 2',
    'Professional Behavior in Maktab Settings',
    [
      {
        text: 'Which of the following is an appropriate approach to behavior management in Maktab settings?',
        options: [
          'Using physical punishment to maintain discipline',
          'Humiliating children who misbehave to discourage others',
          'Using positive reinforcement rather than focusing on negative behavior',
          'Shouting at children to demonstrate authority'
        ],
        correctOption: 2
      },
      {
        text: 'What is an example of appropriate communication with children?',
        options: [
          'Using sarcasm to make points more memorable',
          'Discussing your personal problems to build rapport',
          'Using clear, age-appropriate language and active listening',
          'Making jokes about children\'s appearance or abilities'
        ],
        correctOption: 2
      },
      {
        text: 'How should one-to-one teaching situations be managed?',
        options: [
          'They should be conducted in private, closed rooms',
          'They should be conducted in visible locations with open doors',
          'They should only be conducted by senior staff members',
          'They should never occur under any circumstances'
        ],
        correctOption: 1
      },
      {
        text: 'What aspects of professional appearance and conduct are important in Maktab settings?',
        options: [
          'Wearing expensive clothing to command respect',
          'Dressing modestly in accordance with the setting\'s dress code',
          'Using personal mobile phones regularly to stay connected',
          'Maintaining a distance from colleagues to appear more professional'
        ],
        correctOption: 1
      },
      {
        text: 'How can Islamic concepts of adab (good manners) and akhlaq (character) be incorporated into professional behavior?',
        options: [
          'They are only relevant during religious instruction',
          'They should be expected from children but not from staff',
          'Staff should model these values in their own conduct and interactions',
          'They are outdated concepts with little relevance to modern educational settings'
        ],
        correctOption: 2
      }
    ]
  );

  await createQuiz(
    'quiz-7-3',
    'Introduction to Safe Conduct Quiz 3',
    'Recognizing Concerning Staff Behavior',
    [
      {
        text: 'Which of the following behaviors from a staff member might be cause for concern?',
        options: [
          'Following the organization\'s safeguarding policy',
          'Seeking opportunities to be alone with specific children',
          'Maintaining appropriate professional boundaries',
          'Reporting concerns about colleagues\' behavior'
        ],
        correctOption: 1
      },
      {
        text: 'What is grooming in the context of safeguarding?',
        options: [
          'Helping children maintain good personal hygiene',
          'A process where someone builds a relationship with a child to manipulate, exploit or abuse them',
          'Teaching children about appropriate appearance',
          'Preparing children for religious ceremonies'
        ],
        correctOption: 1
      },
      {
        text: 'What does it mean for staff to be in a "position of trust"?',
        options: [
          'They are trusted to handle the organization\'s finances',
          'They have legal and ethical responsibilities due to their authority over children',
          'They are exempt from certain safeguarding requirements',
          'They can make exceptions to safeguarding policies when necessary'
        ],
        correctOption: 1
      },
      {
        text: 'What should you do if you have concerns about a colleague\'s behavior toward children?',
        options: [
          'Discuss your concerns with other colleagues to get their opinions',
          'Approach the colleague directly to question their behavior',
          'Report your concerns to the Designated Safeguarding Lead',
          'Wait to see if the behavior continues before taking action'
        ],
        correctOption: 2
      },
      {
        text: 'How can organizations create a protective culture that prevents inappropriate behavior?',
        options: [
          'By implementing strict hierarchies where junior staff cannot question seniors',
          'By handling all concerns internally without external involvement',
          'By encouraging open communication and transparency',
          'By limiting staff interaction with children'
        ],
        correctOption: 2
      }
    ]
  );

  // Leadership Tier: 5 new lessons
  await createQuiz(
    'quiz-leadership-1-1',
    'Safe Recruitment and Staff Management Quiz 1',
    'Safe Recruitment Principles',
    [
      {
        text: 'Why is safe recruitment important in Maktabs and Madrasahs?',
        options: [
          'It is only necessary for full-time staff',
          'It helps prevent unsuitable individuals from working with children',
          'It is optional for religious institutions',
          'It only matters for recently established organizations'
        ],
        correctOption: 1
      },
      {
        text: 'Which of the following is NOT a key element of safe recruitment?',
        options: [
          'Obtaining and verifying references before appointment',
          'Including safeguarding questions in interviews',
          'Hiring based primarily on religious knowledge',
          'Requiring full employment history with no gaps'
        ],
        correctOption: 2
      },
      {
        text: 'Which level of DBS check is required for staff in teaching/supervisory roles in Maktabs?',
        options: [
          'Basic DBS',
          'Standard DBS',
          'Enhanced DBS',
          'Enhanced DBS with Barred List'
        ],
        correctOption: 3
      },
      {
        text: 'How should Maktabs handle the recruitment of community members or relatives?',
        options: [
          'They should be exempt from formal checks due to their community standing',
          'They should undergo less rigorous checks than external candidates',
          'They should be subject to the same rigorous safe recruitment processes as all candidates',
          'They should only be checked if there are specific concerns'
        ],
        correctOption: 2
      },
      {
        text: 'What should be included in a job description for a Maktab teaching position?',
        options: [
          'Religious qualifications only',
          'Teaching experience only',
          'Safeguarding responsibilities and expectations',
          'Flexibility to change roles without notice'
        ],
        correctOption: 2
      }
    ]
  );

  await createQuiz(
    'quiz-leadership-1-2',
    'Safe Recruitment and Staff Management Quiz 2',
    'Staff Code of Conduct',
    [
      {
        text: 'What is the primary purpose of a staff code of conduct?',
        options: [
          'To restrict staff freedom and autonomy',
          'To set clear expectations for professional behavior and protect both children and staff',
          'To satisfy external inspectors',
          'To create a hierarchical structure within the organization'
        ],
        correctOption: 1
      },
      {
        text: 'Which of the following should be addressed in a comprehensive code of conduct?',
        options: [
          'Staff members\' religious beliefs',
          'Staff members\' political affiliations',
          'Appropriate physical contact with children',
          'Staff members\' personal financial situations'
        ],
        correctOption: 2
      },
      {
        text: 'What guidance should a code of conduct provide regarding physical contact?',
        options: [
          'All physical contact should be avoided in all circumstances',
          'Physical contact is appropriate whenever staff feel it is necessary',
          'Touch should be in response to a child\'s needs, not the adult\'s, and should be age-appropriate',
          'Physical contact is only appropriate for senior staff members'
        ],
        correctOption: 2
      },
      {
        text: 'How should a code of conduct be implemented in a Maktab or Madrasah?',
        options: [
          'It should be kept confidential among senior leadership',
          'It should be provided to all staff and volunteers during induction with signed acknowledgment',
          'It should only be shared when problems arise',
          'It should be implemented differently for different staff members'
        ],
        correctOption: 1
      },
      {
        text: 'How can Islamic values be incorporated into a staff code of conduct?',
        options: [
          'By focusing exclusively on religious practices',
          'By exempting religious teachers from certain standards',
          'By emphasizing concepts like amanah (trust) and the Prophet\'s gentle treatment of children',
          'By requiring staff to follow specific madhabs (schools of thought)'
        ],
        correctOption: 2
      }
    ]
  );

  await createQuiz(
    'quiz-leadership-1-3',
    'Safe Recruitment and Staff Management Quiz 3',
    'Managing Allegations Against Staff',
    [
      {
        text: 'What types of allegations against staff require formal procedures?',
        options: [
          'Only allegations of physical abuse',
          'Only allegations made by parents',
          'Allegations that a staff member has harmed, committed a criminal offense against, or behaved inappropriately toward a child',
          'Only allegations that have supporting evidence'
        ],
        correctOption: 2
      },
      {
        text: 'What should be the first response when an allegation is made against a staff member?',
        options: [
          'Dismiss the allegation if the staff member has a good reputation',
          'Conduct your own investigation to determine if it\'s valid',
          'Take the allegation seriously and report it immediately to the Designated Safeguarding Lead',
          'Confront the staff member with the allegation'
        ],
        correctOption: 2
      },
      {
        text: 'Who should be notified externally when an allegation is made against a staff member?',
        options: [
          'No external notification is necessary',
          'Only the police in criminal cases',
          'The Local Authority Designated Officer (LADO) within one working day',
          'The entire parent community for transparency'
        ],
        correctOption: 2
      },
      {
        text: 'How should the accused staff member be supported during an allegation investigation?',
        options: [
          'They should be presumed guilty until proven innocent',
          'They should continue all duties as normal',
          'They should be provided with a named contact, advice not to discuss the case, and access to support',
          'They should be immediately dismissed to protect the organization'
        ],
        correctOption: 2
      },
      {
        text: 'What does a "substantiated" outcome mean in an allegation investigation?',
        options: [
          'The allegation was deliberately invented',
          'There is sufficient evidence to prove the allegation',
          'There is insufficient evidence to prove or disprove the allegation',
          'The allegation has no evidence or proper basis'
        ],
        correctOption: 1
      }
    ]
  );

  await createQuiz(
    'quiz-leadership-2-4',
    'Creating a Safeguarding Culture Quiz',
    'Leading on Cultural Sensitivity',
    [
      {
        text: 'What does cultural competence in safeguarding leadership involve?',
        options: [
          'Applying the same approaches to all families regardless of background',
          'Recognizing how cultural factors influence perceptions while maintaining safeguarding standards',
          'Allowing cultural practices to override safeguarding concerns',
          'Focusing only on religious aspects of families\' lives'
        ],
        correctOption: 1
      },
      {
        text: 'How can leaders create culturally sensitive safeguarding policies?',
        options: [
          'By copying policies from mainstream schools without adaptation',
          'By exempting certain cultural practices from scrutiny',
          'By involving diverse community members in policy development',
          'By creating separate policies for different cultural groups'
        ],
        correctOption: 2
      },
      {
        text: 'What approach should leaders take when cultural practices conflict with UK safeguarding standards?',
        options: [
          'Always defer to cultural practices to show respect',
          'Develop frameworks for assessing practices through a safeguarding lens while maintaining respect',
          'Ignore cultural aspects entirely and apply strict UK standards',
          'Allow each staff member to make their own judgment'
        ],
        correctOption: 1
      },
      {
        text: 'How can leaders build a culturally competent safeguarding team?',
        options: [
          'Hire only staff from specific cultural backgrounds',
          'Avoid discussing cultural differences to prevent conflict',
          'Provide training on cultural competence and create opportunities to explore cultural assumptions',
          'Focus only on technical safeguarding skills'
        ],
        correctOption: 2
      },
      {
        text: 'What is an effective approach to engaging with diverse communities on safeguarding?',
        options: [
          'Communicating that UK standards must replace cultural practices',
          'Building relationships with community leaders and using Islamic teachings to reinforce safeguarding',
          'Minimizing discussion of safeguarding to avoid cultural sensitivities',
          'Implementing safeguarding measures without community consultation'
        ],
        correctOption: 1
      }
    ]
  );

  await createQuiz(
    'quiz-leadership-2-5',
    'Creating a Safeguarding Culture Quiz',
    'Overseeing Reporting Procedures',
    [
      {
        text: 'What are leaders\' responsibilities in establishing reporting pathways?',
        options: [
          'Creating complex procedures that only trained professionals can follow',
          'Establishing clear, accessible reporting procedures for all types of concerns',
          'Ensuring all concerns are handled internally without external reporting',
          'Delegating all reporting responsibilities to junior staff'
        ],
        correctOption: 1
      },
      {
        text: 'How can leaders build a culture that encourages appropriate reporting?',
        options: [
          'Implementing strict consequences for staff who report concerns that aren\'t substantiated',
          'Keeping reporting procedures confidential to prevent misuse',
          'Creating a no-blame culture that prioritizes child welfare and addresses barriers to reporting',
          'Limiting reporting authority to senior staff only'
        ],
        correctOption: 2
      },
      {
        text: 'What is important in managing the reporting process?',
        options: [
          'Ensuring the Designated Safeguarding Lead handles all aspects without support',
          'Maintaining strict hierarchies for information flow',
          'Ensuring appropriate information sharing while maintaining confidentiality',
          'Prioritizing organizational reputation in all reporting decisions'
        ],
        correctOption: 2
      },
      {
        text: 'How should leaders manage external reporting relationships?',
        options: [
          'Avoiding contact with external agencies whenever possible',
          'Building relationships with local authority safeguarding teams and understanding thresholds',
          'Allowing each staff member to contact external agencies as they see fit',
          'Reporting all minor concerns to external agencies'
        ],
        correctOption: 1
      },
      {
        text: 'What quality assurance measures should leaders implement for reporting systems?',
        options: [
          'Focusing only on the number of reports made',
          'Regularly auditing safeguarding reports and analyzing patterns',
          'Implementing complex documentation requirements',
          'Limiting review to cases that resulted in external intervention'
        ],
        correctOption: 1
      }
    ]
  );

  // DSL Tier: 3 new lessons
  await createQuiz(
    'quiz-dsl-1-1',
    'The DSL Role and Responsibilities Quiz',
    'Legal Framework for DSLs',
    [
      {
        text: 'Which legislation or guidance establishes the role of organizational safeguarding leads?',
        options: [
          'Health and Safety at Work Act',
          'Working Together to Safeguard Children',
          'Education Act',
          'GDPR regulations'
        ],
        correctOption: 1
      },
      {
        text: 'What are the core legal responsibilities of a DSL?',
        options: [
          'Handling all teaching related to safeguarding topics',
          'Managing referrals, working with others, undertaking training, raising awareness, and maintaining records',
          'Conducting investigations into allegations against staff',
          'Providing therapeutic support to children who have experienced abuse'
        ],
        correctOption: 1
      },
      {
        text: 'What are the potential consequences of a DSL failing to follow proper procedures?',
        options: [
          'There are no serious consequences as the role is advisory only',
          'Personal and organizational liability for safeguarding failures',
          'Consequences only apply in mainstream schools, not supplementary education',
          'Only financial penalties for the organization'
        ],
        correctOption: 1
      },
      {
        text: 'What authority does a DSL have regarding making referrals to external agencies?',
        options: [
          'DSLs must always get management approval before making referrals',
          'DSLs have the authority to make referrals without management approval when necessary',
          'DSLs can only make referrals for serious physical abuse',
          'DSLs should always delegate referral decisions to trustees'
        ],
        correctOption: 1
      },
      {
        text: 'How should DSLs in Maktabs balance religious law with UK safeguarding requirements?',
        options: [
          'Religious law always takes precedence in Islamic settings',
          'UK safeguarding requirements should be ignored when they conflict with religious practices',
          'DSLs must ensure compliance with UK legal frameworks while being sensitive to religious contexts',
          'DSLs should create their own hybrid system based on personal judgment'
        ],
        correctOption: 2
      }
    ]
  );

  await createQuiz(
    'quiz-dsl-2-1',
    'Advanced Case Management Quiz',
    'Assessment and Decision-Making',
    [
      {
        text: 'What is the purpose of using assessment frameworks in safeguarding?',
        options: [
          'To create unnecessary paperwork',
          'To provide structured approaches to evaluating concerns consistently',
          'To replace professional judgment',
          'To delay decision-making'
        ],
        correctOption: 1
      },
      {
        text: 'Which of the following is NOT a recognized level in safeguarding thresholds?',
        options: [
          'Universal (no additional needs)',
          'Early Help (emerging needs)',
          'Moderate Concern (potential issues)',
          'Child Protection (risk of significant harm)'
        ],
        correctOption: 2
      },
      {
        text: 'What is an evidence-based approach to decision-making?',
        options: [
          'Making decisions based on personal opinions',
          'Following the same process for every case regardless of circumstances',
          'Gathering and evaluating information systematically before reaching conclusions',
          'Always deferring to the most experienced professional'
        ],
        correctOption: 2
      },
      {
        text: 'How should cultural factors be considered in safeguarding assessment?',
        options: [
          'Cultural practices should always be accepted regardless of impact',
          'Cultural factors should be ignored to ensure equality',
          'Cultural context should be understood while maintaining focus on the child\'s safety',
          'Assessment should focus only on religious aspects of family life'
        ],
        correctOption: 2
      },
      {
        text: 'What should be included in documentation of safeguarding decisions?',
        options: [
          'Only the final decision without supporting rationale',
          'Personal opinions about the family\'s cultural practices',
          'The rationale for decisions, consultations sought, and alternatives considered',
          'Only information that supports the chosen course of action'
        ],
        correctOption: 2
      }
    ]
  );

  await createQuiz(
    'quiz-dsl-3-1',
    'Specific Safeguarding Issues Quiz',
    'Harmful Cultural Practices',
    [
      {
        text: 'Which of the following is considered a harmful cultural practice that DSLs should be aware of?',
        options: [
          'Celebrating religious festivals',
          'Speaking heritage languages at home',
          'Forced marriage',
          'Traditional modest dress'
        ],
        correctOption: 2
      },
      {
        text: 'Under which UK legislation is Female Genital Mutilation (FGM) illegal?',
        options: [
          'Children Act 1989',
          'Female Genital Mutilation Act 2003',
          'Equality Act 2010',
          'Education Act 2002'
        ],
        correctOption: 1
      },
      {
        text: 'What is a potential warning sign that a child might be at risk of forced marriage?',
        options: [
          'Participating in religious education',
          'Wearing traditional cultural clothing',
          'Absence from school, surveillance by siblings, and decline in performance',
          'Speaking their heritage language'
        ],
        correctOption: 2
      },
      {
        text: 'What is the appropriate response when you identify potential risk of a harmful cultural practice?',
        options: [
          'Address it only within the community without external involvement',
          'Respect it as a cultural choice regardless of harm',
          'Involve specialist agencies with cultural expertise and follow safeguarding procedures',
          'Wait for absolute proof before taking any action'
        ],
        correctOption: 2
      },
      {
        text: 'What is an accurate statement about the relationship between Islam and harmful cultural practices?',
        options: [
          'Islam requires all cultural practices followed by Muslims',
          'Many harmful practices are misattributed to Islam when they are actually cultural practices',
          'Islamic teachings cannot be used to challenge harmful practices',
          'All traditional practices in Muslim communities are required by religion'
        ],
        correctOption: 1
      }
    ]
  );

  // Trustee Tier: 5 new lessons
  await createQuiz(
    'quiz-trustee-1-1',
    'Governance Responsibilities Quiz',
    'Legal Duties of Trustees',
    [
      {
        text: 'What is the primary safeguarding responsibility of trustees in a Maktab or Madrasah?',
        options: [
          'Handling day-to-day safeguarding concerns',
          'Taking ultimate responsibility for safeguarding within the organization',
          'Conducting safeguarding investigations personally',
          'Providing direct support to children who have experienced abuse'
        ],
        correctOption: 1
      },
      {
        text: 'Under Charity Commission guidance, what are trustees required to do regarding safeguarding?',
        options: [
          'Delegate all safeguarding responsibilities to staff',
          'Focus only on financial aspects of the organization',
          'Ensure appropriate policies, procedures, and resources are in place for safeguarding',
          'Report all minor concerns directly to the Charity Commission'
        ],
        correctOption: 2
      },
      {
        text: 'What can be the consequences of governance failures in safeguarding?',
        options: [
          'There are no serious consequences as trustees are volunteers',
          'Only the organization faces consequences, not individual trustees',
          'Personal and collective liability of trustees, potential Charity Commission intervention',
          'Only reputational damage with no legal implications'
        ],
        correctOption: 2
      },
      {
        text: 'What constitutes a "serious incident" that must be reported to the Charity Commission?',
        options: [
          'Any safeguarding concern, no matter how minor',
          'Only incidents that result in police involvement',
          'Harm or alleged harm to beneficiaries, significant breaches of procedures',
          'Only incidents that appear in the media'
        ],
        correctOption: 2
      },
      {
        text: 'When there is a potential conflict between religious practices and safeguarding duties, what should trustees do?',
        options: [
          'Always prioritize religious practices',
          'Understand that UK law takes precedence when conflicts arise',
          'Create exemptions from safeguarding requirements based on religious grounds',
          'Allow each staff member to decide based on their own religious interpretation'
        ],
        correctOption: 1
      }
    ]
  );

  await createQuiz(
    'quiz-trustee-1-2',
    'Governance Responsibilities Quiz',
    'Governance Structures and Systems',
    [
      {
        text: 'Which of the following is an effective governance structure for safeguarding oversight?',
        options: [
          'Having no specific safeguarding governance as it\'s an operational matter',
          'Assigning safeguarding to the newest trustee as a learning opportunity',
          'Having a dedicated safeguarding trustee or committee with clear terms of reference',
          'Discussing safeguarding only when incidents occur'
        ],
        correctOption: 2
      },
      {
        text: 'Which policies require trustee approval in a comprehensive safeguarding framework?',
        options: [
          'Only the main safeguarding policy',
          'Safeguarding policy, code of conduct, safer recruitment policy, and whistleblowing policy',
          'Only policies that relate to serious abuse',
          'Only policies required by external funders'
        ],
        correctOption: 1
      },
      {
        text: 'How should trustees monitor safeguarding in their organization?',
        options: [
          'By handling all safeguarding concerns personally',
          'By receiving regular reports, reviewing key indicators, and conducting annual audits',
          'By leaving all monitoring to the Designated Safeguarding Lead',
          'By focusing only on incidents that reach external agencies'
        ],
        correctOption: 1
      },
      {
        text: 'How should safeguarding risks be managed at governance level?',
        options: [
          'Risks should be handled entirely by operational staff',
          'Including safeguarding in organizational risk registers with regular review',
          'Focusing only on financial and reputational risks',
          'Addressing risks only after incidents occur'
        ],
        correctOption: 1
      },
      {
        text: 'What is the appropriate balance between governance oversight and operational management in safeguarding?',
        options: [
          'Trustees should manage all safeguarding operations directly',
          'Trustees should have no involvement in safeguarding as it\'s operational',
          'Clear delegation of operations to staff while maintaining appropriate governance oversight',
          'Trustees should only be involved in the most serious cases'
        ],
        correctOption: 2
      }
    ]
  );

  await createQuiz(
    'quiz-trustee-1-3',
    'Governance Responsibilities Quiz',
    'Creating a Safeguarding Culture',
    [
      {
        text: 'What is a key characteristic of a strong safeguarding culture?',
        options: [
          'Handling all concerns internally without external involvement',
          'Focusing primarily on the organization\'s reputation',
          'A child-centered approach that prioritizes children\'s welfare in all decisions',
          'Strict hierarchies where junior staff cannot question seniors'
        ],
        correctOption: 2
      },
      {
        text: 'How can trustees model safeguarding leadership?',
        options: [
          'By delegating all safeguarding responsibilities to staff',
          'By demonstrating visible commitment and allocating adequate resources',
          'By avoiding discussions about safeguarding at board meetings',
          'By focusing only on policy documents rather than practice'
        ],
        correctOption: 1
      },
      {
        text: 'How can trustees engage the wider community in safeguarding?',
        options: [
          'By keeping safeguarding arrangements confidential',
          'By communicating expectations and working with community leaders',
          'By allowing community leaders to override safeguarding decisions',
          'By implementing measures without community consultation'
        ],
        correctOption: 1
      },
      {
        text: 'How should trustees address resistance to safeguarding measures?',
        options: [
          'By abandoning measures that face resistance',
          'By imposing measures without addressing concerns',
          'By understanding reasons for resistance and demonstrating compatibility with Islamic values',
          'By implementing different standards for different community members'
        ],
        correctOption: 2
      },
      {
        text: 'How can trustees measure progress in developing a safeguarding culture?',
        options: [
          'By counting the number of safeguarding policies',
          'By the absence of serious incidents',
          'Through surveys, feedback, monitoring reporting patterns, and observing practices',
          'By comparing with mainstream schools only'
        ],
        correctOption: 2
      }
    ]
  );

  await createQuiz(
    'quiz-trustee-1-4',
    'Governance Responsibilities Quiz',
    'Governance Oversight of Safe Recruitment',
    [
      {
        text: 'Why should trustees prioritize safe recruitment?',
        options: [
          'It is only necessary for paid staff positions',
          'To prevent unsuitable individuals from gaining access to children',
          'Only to comply with external requirements',
          'It is less important than other safeguarding measures'
        ],
        correctOption: 1
      },
      {
        text: 'What are trustees\' key responsibilities regarding safe recruitment?',
        options: [
          'Conducting all recruitment personally',
          'Ensuring comprehensive policies are in place and monitoring compliance',
          'Focusing only on senior staff recruitment',
          'Delegating all recruitment responsibilities to staff'
        ],
        correctOption: 1
      },
      {
        text: 'Which of the following is an essential element of safe recruitment that trustees should ensure?',
        options: [
          'Hiring primarily based on religious knowledge',
          'Conducting thorough interviews including safeguarding questions',
          'Expediting the process for community members',
          'Relying primarily on character references from community leaders'
        ],
        correctOption: 1
      },
      {
        text: 'What level of DBS check should trustees ensure is conducted for those in regulated activity with children?',
        options: [
          'Basic DBS',
          'Standard DBS',
          'Enhanced DBS',
          'Enhanced DBS with Barred List'
        ],
        correctOption: 3
      },
      {
        text: 'How should trustees address cultural considerations in safe recruitment?',
        options: [
          'By exempting community members from checks',
          'By implementing less rigorous standards for religious teachers',
          'By ensuring consistent standards while explaining their importance sensitively',
          'By allowing cultural practices to override safeguarding requirements'
        ],
        correctOption: 2
      }
    ]
  );

  await createQuiz(
    'quiz-trustee-2-7',
    'Strategic Oversight Quiz',
    'Cultural Sensitivity at Governance Level',
    [
      {
        text: 'What does cultural sensitivity at governance level mean?',
        options: [
          'Exempting certain cultural practices from safeguarding scrutiny',
          'Respecting diversity while prioritizing child safety',
          'Implementing different safeguarding standards for different cultural groups',
          'Focusing exclusively on religious aspects of safeguarding'
        ],
        correctOption: 1
      },
      {
        text: 'How can trustees create culturally sensitive governance structures?',
        options: [
          'By excluding community members from governance',
          'By ensuring diverse representation and creating accessible processes',
          'By having separate governance structures for different cultural groups',
          'By focusing only on religious qualifications for trustees'
        ],
        correctOption: 1
      },
      {
        text: 'What approach should trustees take to developing culturally sensitive policies?',
        options: [
          'Copying policies from mainstream organizations without adaptation',
          'Creating policies that exempt cultural practices from scrutiny',
          'Involving diverse community members in policy development',
          'Implementing policies without community consultation'
        ],
        correctOption: 2
      },
      {
        text: 'How should trustees navigate situations where cultural practices may conflict with safeguarding standards?',
        options: [
          'Always defer to cultural practices',
          'Ignore cultural context entirely',
          'Develop frameworks for assessment that balance respect with child safety',
          'Allow each staff member to make individual judgments'
        ],
        correctOption: 2
      },
      {
        text: 'How can trustees build cultural bridges with external agencies?',
        options: [
          'By avoiding contact with external agencies',
          'By developing relationships and addressing misconceptions about Islamic settings',
          'By demanding special treatment for religious organizations',
          'By implementing separate systems that don\'t interact with statutory services'
        ],
        correctOption: 1
      }
    ]
  );

  console.log('Seeding completed successfully');
}

/**
 * Helper function to create a quiz with questions
 */
async function createQuiz(
  quizId: string,
  title: string,
  description: string,
  questions: { text: string; options: string[]; correctOption: number }[]
) {
  // First, find the module associated with this quiz ID
  const modulePattern = quizId.startsWith('quiz-leadership') 
    ? 'module-' + quizId.split('-')[2] // For leadership tier
    : quizId.startsWith('quiz-dsl') || quizId.startsWith('quiz-trustee')
      ? 'module-' + quizId.split('-')[2] // For DSL and Trustee tiers
      : 'module-' + quizId.split('-')[1]; // For foundation tier

  const module = await prisma.module.findFirst({
    where: {
      id: { startsWith: modulePattern }
    }
  });

  if (!module) {
    console.error(`Module not found for quiz ID: ${quizId}`);
    return;
  }

  // Create the quiz
  const quiz = await prisma.quiz.create({
    data: {
      id: quizId,
      title: title,
      moduleId: module.id,
      questions: {
        create: questions.map(q => ({
          text: q.text,
          options: q.options,
          correctOption: q.correctOption
        }))
      }
    }
  });

  console.log(`Created quiz: ${quiz.id}`);
}

main()
  .catch((e) => {
    console.error(e);
    process.exit(1);
  })
  .finally(async () => {
    await prisma.$disconnect();
  });
